
/*----------------------------------------------------------------------------*

	LinuxInfo_intel.c
		by Alex Buell
			September 1998

 ----------------------------------------------------------------------------- 

	Handles the Intel architecture	

 ----------------------------------------------------------------------------- 

	HISTORY

	1.01 - Initial development

 -----------------------------------------------------------------------------*/

#include "linuxinfo.h"

#ifdef system_intel

void GetHardwareInfo(struct hw_stat *hw)
{
	int processors = 0; 
	float bogomips = 0.0;
	float tempbogo;
	LONGLONG memory = 0;

	char temp_string[BUFSIZ], temp_string2[BUFSIZ];
	char chip[BUFSIZ], vendor[BUFSIZ], model[BUFSIZ];

	FILE *procfile;
	struct stat st_buf;

	if ((procfile = fopen(CPUINFO_FILE, "r")) != NULL) 
	{
		while (fscanf(procfile, "%s", (char *)&temp_string2) != EOF) 
		{
			if (processors == 0) 
			{
				if (!(strcmp(temp_string2, "cpu"))) 
				{
					fscanf(procfile, "%s%s", (char *)&temp_string, (char *)&chip);
					if (chip[0] == ':')
					{
						fscanf(procfile, "%s", (char *)&temp_string);
						sprintf(chip, "%s86", temp_string);
					}
				}
				if (!(strcmp(temp_string2, "model")))
				{
					fscanf(procfile, "%s", (char *)&temp_string);
					if (!(strcmp(temp_string, "name")))  /* 2.1.120+ only */
						fscanf(procfile, "%s", (char *)&temp_string);

					GetStringFromFile(procfile, (char *)&model);
					sscanf(model, "%s", (char *)&temp_string);

					/* Now convert the information into human-readable format */
					if (!(strcmp(temp_string, "K6")))
						sprintf(model, "%s", "K6");

					if (!(strcmp(temp_string, "AMD-K6tm")))
						sprintf(model, "%s", "K6");

					if (!(strncmp(temp_string, "6x86L", 5)))
						sprintf(model, "%s", "6x86");
	
					if (!(strncmp(temp_string, "6x86M", 5)))
						sprintf(model, "%s", "6x86MMX");

					if (!(strncmp(temp_string, "K5", 2)))
						sprintf(model, "%s", "K5");

					if (!(strcmp(temp_string, "unknown")))
						sprintf(model, "%s", chip);
				}
				if (!(strcmp(temp_string2, "vendor_id"))) 
				{
					fscanf(procfile, "%s", (char *)&temp_string);

					GetStringFromFile(procfile, (char *)&vendor);
					sscanf(vendor, "%s", (char *)&temp_string);

					if (!(strcmp(temp_string, "AuthenticAMD")))
					{
						sprintf(vendor, "%s", "AMD ");
						
						if (model[0] == '6')
							sprintf(model, "%s", "K6");
					}

					if (!(strcmp(temp_string, "GenuineIntel")))
					{
						sprintf(vendor, "%s", "Intel ");

						if (!(strcmp(chip, "585")))
							sprintf(model, "%s", "Pentium");

						if (!(strcmp(chip, "686")))
							if (model[0] == '3')
								sprintf(model, "%s", "Pentium II");
					}

					if (!(strcmp(temp_string, "CyrixInstead")))
						sprintf(vendor, "%s", "Cyrix ");
						
					if (!(strcmp(temp_string, "CentaurHauls")))
						sprintf(vendor, "%s", "Centaur ");	

					if (!(strcmp(temp_string, "unknown")))
						vendor[0] = '\0';
				}
			}
			if (!(strcmp(temp_string2, "bogomips")))
			{
				processors++;
				fscanf(procfile, "%s%f", (char *)&hw->hw_bogomips, &tempbogo);
				bogomips += tempbogo;
			}
		}
		fclose(procfile);
	}

	stat(MEMORY_FILE, &st_buf);
	memory = st_buf.st_size;
	memory /= 1024; memory /= 1024;
	sprintf(hw->hw_memory, "%ld", (long int)memory);

	hw->hw_processors = processors;

	sprintf(hw->hw_cpuinfo, "%s%s", vendor, model);
	sprintf(hw->hw_bogomips, "%0.2f", bogomips);
}

#endif /* system_intel */
